==> mono_1.1.8.2.orig.tar.gz: mono-1.1.8.2/mcs/class/System.Web/System.Web.UI.WebControls.WebParts/WebPartAuthorizationEventArgs.cs <==
//
// System.Web.UI.WebControls.WebParts.WebPartAuthorizationEventArgs.cs
//
// Authors:
//   Sanjay Gupta (gsanjay@novell.com)
//
// (C) 2004 Novell, Inc (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

namespace System.Web.UI.WebControls.WebParts
{
	public class WebPartAuthorizationEventArgs : WebPartEventArgs
	{
		private bool authorized;
		public WebPartAuthorizationEventArgs (WebPart part) : base (part)
		{
			this.authorized = false;
		}
		
		public bool IsAuthorized {
			get { return authorized; }
			set { authorized = value; }
		}
	}
}
#endif

==> mono_3.2.8+dfsg.orig.tar.gz: mono-3.2.8+dfsg/mcs/class/System.Web/System.Web.UI.WebControls.WebParts/WebPartAuthorizationEventArgs.cs <==
//
// System.Web.UI.WebControls.WebParts.WebPartAuthorizationEventArgs.cs
//
// Authors:
//   Sanjay Gupta (gsanjay@novell.com)
//
// (C) 2004 Novell, Inc (http://www.novell.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

namespace System.Web.UI.WebControls.WebParts
{
	public class WebPartAuthorizationEventArgs : EventArgs
	{
		bool authorized;
		Type type;
		string path;
		string authorizationFilter;
		bool isShared;

		public WebPartAuthorizationEventArgs (Type type,
						      string path,
						      string authorizationFilter,
						      bool isShared)
		{
			this.type = type;
			this.path = path;
			this.authorizationFilter = authorizationFilter;
			this.isShared = isShared;
		}

		public Type Type {
			get { return type; }
		}

		public string Path {
			get { return path; }
		}

		public string AuthorizationFilter {
			get { return authorizationFilter; }
		}

		public bool IsShared {
			get { return isShared; }
		}

		public bool IsAuthorized {
			get { return authorized; }
			set { authorized = value; }
		}
	}
}
#endif
